@@ -13,6 +13,7 @@ from . import poses
 from . import graph
 from . import sample
 from . import repair
+from . import unwrap
 from . import convex
 from . import remesh
 from . import bounds
@@ -39,13 +40,13 @@ from .exchange.export import export_mesh
 from .constants import log, log_time, tol
 
 from .scene import Scene
-from .parent import Geometry
+from .parent import Geometry3D
 
 import copy
 import numpy as np
 
 
-class Trimesh(Geometry):
+class Trimesh(Geometry3D):
 
     def __init__(self,
                  vertices=None,
@@ -1002,12 +1003,12 @@ class Trimesh(Geometry):
 
         Examples
         ---------
-        In [0]: mesh.faces[0:2]
+        In [0]: mesh.faces[:2]
         Out[0]:
         TrackedArray([[    1,  6946, 24224],
                       [ 6946,  1727, 24225]])
 
-        In [1]: mesh.edges_unique[mesh.faces_unique_edges[0:2]]
+        In [1]: mesh.edges_unique[mesh.faces_unique_edges[:2]]
         Out[1]:
         array([[[    1,  6946],
                 [ 6946, 24224],
@@ -1049,7 +1050,7 @@ class Trimesh(Geometry):
         referenced : (len(self.vertices), ) bool
           Which vertices are referenced by a face
         """
-        referenced = np.zeros(len(self.vertices), dtype=np.bool)
+        referenced = np.zeros(len(self.vertices), dtype=bool)
         referenced[self.faces] = True
         return referenced
 
@@ -1718,8 +1719,8 @@ class Trimesh(Geometry):
         edges = self.edges_sorted.reshape((-1, 6))
         # get the edges for each facet
         edges_facet = [edges[i].reshape((-1, 2)) for i in self.facets]
-        edges_boundary = np.array([i[grouping.group_rows(i, require_count=1)]
-                                   for i in edges_facet])
+        edges_boundary = [i[grouping.group_rows(i, require_count=1)]
+                          for i in edges_facet]
         return edges_boundary
 
     @caching.cache_decorator
@@ -1734,7 +1735,7 @@ class Trimesh(Geometry):
         """
         # if no facets exit early
         if len(self.facets) == 0:
-            return np.array([], dtype=np.bool)
+            return np.array([], dtype=bool)
 
         # facets plane, origin and normal
         normals = self.facets_normal
@@ -1744,7 +1745,7 @@ class Trimesh(Geometry):
         convex = self.convex_hull.vertices.view(np.ndarray).copy()
 
         # boolean mask for which facets are on convex hull
-        on_hull = np.zeros(len(self.facets), dtype=np.bool)
+        on_hull = np.zeros(len(self.facets), dtype=bool)
 
         for i, normal, origin in zip(range(len(normals)), normals, origins):
             # a facet plane is on the convex hull if every vertex
@@ -2070,17 +2071,21 @@ class Trimesh(Geometry):
     def slice_plane(self,
                     plane_origin,
                     plane_normal,
+                    cap=False,
                     **kwargs):
         """
         Slice the mesh with a plane, returning a new mesh that is the
         portion of the original mesh to the positive normal side of the plane
 
-        Parameters
-        ------------
-        plane_normal: (3) vector for plane normal
-          Normal vector of slicing plane
-        plane_origin : (3, ) float
-          Point on the slicing plane
+        plane_origin :  (3,) float
+          Point on plane to intersect with mesh
+        plane_normal : (3,) float
+          Normal vector of plane to intersect with mesh
+        cap : bool
+          If True, cap the result with a triangulated polygon
+        cached_dots : (n, 3) float
+            If an external function has stored dot
+            products pass them here to avoid recomputing
 
         Returns
         ---------
@@ -2094,10 +2099,30 @@ class Trimesh(Geometry):
             mesh=self,
             plane_normal=plane_normal,
             plane_origin=plane_origin,
+            cap=cap,
             **kwargs)
 
         return new_mesh
 
+    def unwrap(self, **kwargs):
+        """
+        Returns a Trimesh object equivalent to the current mesh where
+        the vertices have been assigned uv texture coordinates.
+
+        The vertices may be split into as many as necessary
+        by the unwrapping algorithm, depending on how many uv maps
+        they appear in.
+
+        Requires blender.
+
+        Returns
+        --------
+        unwrapped : trimesh.Trimesh
+          Mesh with unwrapped uv coordinates
+        """
+        result = unwrap.unwrap(self, **kwargs)
+        return result
+
     @caching.cache_decorator
     def convex_hull(self):
         """
@@ -2142,7 +2167,7 @@ class Trimesh(Geometry):
         Remove all vertices in the current mesh which are not
         referenced by a face.
         """
-        referenced = np.zeros(len(self.vertices), dtype=np.bool)
+        referenced = np.zeros(len(self.vertices), dtype=bool)
         referenced[self.faces] = True
 
         inverse = np.zeros(len(self.vertices), dtype=np.int64)
@@ -2289,6 +2314,41 @@ class Trimesh(Geometry):
         return creation.voxelize(
             mesh=self, pitch=pitch, method=method, **kwargs)
 
+    @caching.cache_decorator
+    def as_open3d(self):
+        """
+        Return an `open3d.geometry.TriangleMesh` version of
+        the current mesh.
+
+        Returns
+        ---------
+        open3d : open3d.geometry.TriangleMesh
+          Current mesh as an open3d object.
+        """
+        import open3d
+        # create from numpy arrays
+        return open3d.geometry.TriangleMesh(
+            vertices=open3d.utility.Vector3dVector(self.vertices),
+            triangles=open3d.utility.Vector3iVector(self.faces))
+
+    def simplify_quadratic_decimation(self, face_count):
+        """
+        A thin wrapper around the open3d implementation of this:
+        `open3d.geometry.TriangleMesh.simplify_quadric_decimation`
+
+        Parameters
+        -----------
+        face_count : int
+          Number of faces desired in the resulting mesh.
+
+        Returns
+        ---------
+        simple : trimesh.Trimesh
+          Simplified version of mesh.
+        """
+        simple = self.as_open3d.simplify_quadric_decimation(int(face_count))
+        return Trimesh(vertices=simple.vertices, faces=simple.triangles)
+
     def outline(self, face_ids=None, **kwargs):
         """
         Given a list of face indexes find the outline of those
@@ -2312,13 +2372,11 @@ class Trimesh(Geometry):
         path : Path3D
           Curve in 3D of the outline
         """
+        from .path import Path3D
         from .path.exchange.misc import faces_to_path
-        from .path.exchange.load import _create_path
-
-        path = _create_path(**faces_to_path(self,
-                                            face_ids,
-                                            **kwargs))
-        return path
+        from .exchange.load import load_kwargs
+        return Path3D(**faces_to_path(
+            self, face_ids, **kwargs))
 
     @caching.cache_decorator
     def area(self):
