@@ -89,7 +89,7 @@ def face_adjacency(faces=None,
     edge_groups = grouping.group_rows(edges, require_count=2)
 
     if len(edge_groups) == 0:
-        log.warning('No adjacent faces detected! Did you merge vertices?')
+        log.debug('No adjacent faces detected! Did you merge vertices?')
 
     # the pairs of all adjacent faces
     # so for every row in face_idx, self.faces[face_idx[*][0]] and
@@ -287,7 +287,7 @@ def facets(mesh, engine=None):
     # a common failure mode is two faces that are very narrow with a slight
     # angle between them, so here we divide by the perpendicular span
     # to penalize very narrow faces, and then square it just for fun
-    parallel = np.ones(len(radii), dtype=np.bool)
+    parallel = np.ones(len(radii), dtype=bool)
     # if span is zero we know faces are small/parallel
     nonzero = np.abs(span) > tol.zero
     # faces with a radii/span ratio larger than a threshold pass
@@ -381,12 +381,7 @@ def connected_components(edges,
         # aren't discarded (as they aren't adjacent to anything)
         if min_len <= 1:
             graph.add_nodes_from(nodes)
-        iterable = nx.connected_components(graph)
-        # newer versions of networkx return sets rather than lists
-        components = np.array(
-            [np.array(list(i), dtype=np.int64)
-             for i in iterable if len(i) >= min_len])
-        return components
+        return [list(i) for i in nx.connected_components(graph)]
 
     def components_csgraph():
         """
@@ -398,12 +393,11 @@ def connected_components(edges,
 
         # we have to remove results that contain nodes outside
         # of the specified node set and reindex
-        contained = np.zeros(node_count, dtype=np.bool)
+        contained = np.zeros(node_count, dtype=bool)
         contained[nodes] = True
         index = np.arange(node_count, dtype=np.int64)[contained]
-
         components = grouping.group(labels[contained], min_len=min_len)
-        components = np.array([index[c] for c in components])
+        return [index[c] for c in components]
 
         return components
 
@@ -415,12 +409,12 @@ def connected_components(edges,
 
     # exit early if we have no nodes
     if len(nodes) == 0:
-        return np.array([])
+        return []
     elif len(edges) == 0:
         if min_len <= 1:
-            return np.reshape(nodes, (-1, 1))
+            return np.reshape(nodes, (-1, 1)).tolist()
         else:
-            return np.array([])
+            return []
 
     if not util.is_shape(edges, (-1, 2)):
         raise ValueError('edges must be (n, 2)!')
@@ -434,7 +428,7 @@ def connected_components(edges,
     node_count = np.max(counts) + 1
 
     # remove edges that don't have both nodes in the node set
-    mask = np.zeros(node_count, dtype=np.bool)
+    mask = np.zeros(node_count, dtype=bool)
     mask[nodes] = True
     edges_ok = mask[edges].all(axis=1)
     edges = edges[edges_ok]
@@ -454,9 +448,9 @@ def connected_components(edges,
         try:
             return function()
         # will be raised if the library didn't import correctly above
-        except NameError:
+        except BaseException:
             continue
-    raise ImportError('No connected component engines available!')
+    raise ImportError('no graph engines available!')
 
 
 def connected_component_labels(edges, node_count=None):
@@ -553,9 +547,8 @@ def split_traversal(traversal,
         # if we need the edge add it
         if close in edges_hash:
             split[i] = np.append(t, t[0]).astype(np.int64)
-    result = np.array(split)
 
-    return result
+    return split
 
 
 def fill_traversals(traversals, edges, edges_hash=None):
@@ -714,7 +707,7 @@ def edges_to_coo(edges, count=None, data=None):
     # if no data is specified set every specified edge
     # to True
     if data is None:
-        data = np.ones(len(edges), dtype=np.bool)
+        data = np.ones(len(edges), dtype=bool)
 
     matrix = coo_matrix((data, edges.T),
                         dtype=data.dtype,
@@ -807,7 +800,7 @@ def smoothed(mesh, angle=None, facet_minarea=15):
                 # mask for removing adjacency pairs where
                 # one of the faces is contained in a facet
                 mask = np.ones(len(mesh.faces),
-                               dtype=np.bool)
+                               dtype=bool)
                 mask[np.hstack(facets)] = False
                 # apply the mask to adjacency
                 adjacency = adjacency[
@@ -821,7 +814,7 @@ def smoothed(mesh, angle=None, facet_minarea=15):
     components = connected_components(
         adjacency,
         min_len=1,
-        nodes=nodes).tolist()
+        nodes=nodes)
 
     # add back coplanar groups if any exist
     if len(facets) > 0:
