@@ -55,11 +55,11 @@ def merge_vertices(mesh,
     # if we have a ton of unreferenced vertices it will
     # make the unique_rows call super slow so cull first
     if hasattr(mesh, 'faces') and len(mesh.faces) > 0:
-        referenced = np.zeros(len(mesh.vertices), dtype=np.bool)
+        referenced = np.zeros(len(mesh.vertices), dtype=bool)
         referenced[mesh.faces] = True
     else:
         # this is used for geometry without faces
-        referenced = np.ones(len(mesh.vertices), dtype=np.bool)
+        referenced = np.ones(len(mesh.vertices), dtype=bool)
 
     # collect vertex attributes into sequence we can stack
     stacked = [mesh.vertices * (10 ** digits_vertex)]
@@ -140,8 +140,6 @@ def group(values, min_len=0, max_len=np.inf):
     groups = [order[i:(i + j)]
               for i, j in zip(dupe_idx[dupe_ok],
                               dupe_len[dupe_ok])]
-    groups = np.array(groups)
-
     return groups
 
 
@@ -230,7 +228,7 @@ def float_to_int(data, digits=None, dtype=np.int32):
     # populate digits from kwargs
     if digits is None:
         digits = util.decimal_to_digits(tol.merge)
-    elif isinstance(digits, float) or isinstance(digits, np.float):
+    elif isinstance(digits, float) or isinstance(digits, np.float64):
         digits = util.decimal_to_digits(digits)
     elif not (isinstance(digits, int) or isinstance(digits, np.integer)):
         log.warning('Digits were passed as %s!', digits.__class__.__name__)
@@ -317,7 +315,7 @@ def unique_bincount(values,
 
     # which bins are occupied at all
     # counts are integers so this works
-    unique_bin = counts.astype(np.bool)
+    unique_bin = counts.astype(bool)
 
     # which values are unique
     # indexes correspond to original values
@@ -475,7 +473,7 @@ def unique_value_in_row(data, unique=None):
     if unique is None:
         unique = np.unique(data)
     data = np.asanyarray(data)
-    result = np.zeros_like(data, dtype=np.bool, subok=False)
+    result = np.zeros_like(data, dtype=bool, subok=False)
     for value in unique:
         test = np.equal(data, value)
         test_ok = test.sum(axis=1) == 1
@@ -526,7 +524,7 @@ def group_rows(data, require_count=None, digits=None):
                 observed[key_string].append(index)
             else:
                 observed[key_string] = [index]
-        return np.array(list(observed.values()))
+        return list(observed.values())
 
     def group_slice():
         # create a representation of the rows that can be sorted
@@ -650,7 +648,7 @@ def group_distance(values, distance):
                            dtype=np.float64)
 
     consumed = np.zeros(len(values),
-                        dtype=np.bool)
+                        dtype=bool)
     tree = cKDTree(values)
 
     # (n, d) set of values that are unique
@@ -662,11 +660,11 @@ def group_distance(values, distance):
         if consumed[index]:
             continue
         group = np.array(tree.query_ball_point(value, distance),
-                         dtype=np.int)
+                         dtype=np.int64)
         consumed[group] = True
         unique.append(np.median(values[group], axis=0))
         groups.append(group)
-    return np.array(unique), np.array(groups)
+    return np.array(unique), groups
 
 
 def clusters(points, radius):
@@ -731,9 +729,8 @@ def blocks(data,
 
     # find the inflection points
     # AKA locations where the array goes from True to False.
-    infl = np.concatenate(([0],
-                           np.nonzero(np.diff(data))[0] + 1,
-                           [len(data)]))
+    infl = np.concatenate((
+        [0], np.nonzero(np.diff(data))[0] + 1, [len(data)]))
     infl_len = np.diff(infl)
     # check the length of each group
     infl_ok = np.logical_and(infl_len >= min_len,
