@@ -90,7 +90,7 @@ def mesh_plane(mesh,
         # of both on- edge cases ([6,16])
         # this is so that for regions that are co-planar with the the section plane
         # we don't end up with an invalid boundary
-        key = np.zeros(29, dtype=np.bool)
+        key = np.zeros(29, dtype=bool)
         key[16] = True
         one_edge = key[coded]
 
@@ -616,8 +616,10 @@ def slice_mesh_plane(mesh,
     cap : bool
       If True, cap the result with a triangulated polygon
     cached_dots : (n, 3) float
-        If an external function has stored dot
-        products pass them here to avoid recomputing
+      If an external function has stored dot
+      products pass them here to avoid recomputing
+    kwargs : dict
+      Passed to the newly created sliced mesh
 
     Returns
     ----------
@@ -718,12 +720,19 @@ def slice_mesh_plane(mesh,
             if check.astype(np.float64).mean() > 0.5:
                 ff = np.fliplr(ff)
 
+            # check vertices to see which ones are on plane
+            on_plane = np.abs(np.dot(vertices - origin, normal)) < tol.merge
             # add cap vertices and faces and reindex
-            vertices, faces = util.append_faces([vertices, vf], [faces, ff])
+            # remove any original faces which are coplanar with cap plane
+            # as these will be replaced by newly generated faces
+            vertices, faces = util.append_faces(
+                [vertices, vf], [faces[~on_plane[faces].all(axis=1)], ff])
 
             # Update mesh with cap (processing needed to merge vertices)
             sliced_mesh = Trimesh(vertices=vertices, faces=faces)
             vertices, faces = sliced_mesh.vertices.copy(), sliced_mesh.faces.copy()
 
     # return the sliced mesh
-    return Trimesh(vertices=vertices, faces=faces, process=False)
+    if 'process' not in kwargs:
+        kwargs['process'] = False
+    return Trimesh(vertices=vertices, faces=faces, **kwargs)
