@@ -42,6 +42,7 @@ class SceneViewer(pyglet.window.Window):
                  caption=None,
                  fixed=None,
                  offset_lines=True,
+                 line_settings=None,
                  background=None,
                  window_conf=None,
                  profile=False,
@@ -134,6 +135,15 @@ class SceneViewer(pyglet.window.Window):
         else:
             scene.camera.resolution = resolution
 
+        # set the default line settings to a fraction
+        # of our resolution so the points aren't tiny
+        scale = max(resolution)
+        self.line_settings = {'point_size': scale / 200,
+                              'line_width': scale / 400}
+        # if we've been passed line settings override the default
+        if line_settings is not None:
+            self.line_settings.update(line_settings)
+
         # no window conf was passed so try to get the best looking one
         if window_conf is None:
             try:
@@ -222,8 +232,14 @@ class SceneViewer(pyglet.window.Window):
         kwargs **
           Passed to rendering.convert_to_vertexlist
         """
-        # convert geometry to constructor args
-        args = rendering.convert_to_vertexlist(geometry, **kwargs)
+        try:
+            # convert geometry to constructor args
+            args = rendering.convert_to_vertexlist(geometry, **kwargs)
+        except BaseException:
+            util.log.warning('failed to add geometry `{}`'.format(name),
+                             exc_info=True)
+            return
+
         # create the indexed vertex list
         self.vertex_list[name] = self.batch.add_indexed(*args)
         # save the hash of the geometry
@@ -340,7 +356,7 @@ class SceneViewer(pyglet.window.Window):
         self._gl_enable_depth(self.scene.camera)
         self._gl_enable_color_material()
         self._gl_enable_blending()
-        self._gl_enable_smooth_lines()
+        self._gl_enable_smooth_lines(**self.line_settings)
         self._gl_enable_lighting(self.scene)
 
     @staticmethod
@@ -400,14 +416,14 @@ class SceneViewer(pyglet.window.Window):
                        gl.GL_ONE_MINUS_SRC_ALPHA)
 
     @staticmethod
-    def _gl_enable_smooth_lines():
+    def _gl_enable_smooth_lines(line_width=4, point_size=4):
         # make the lines from Path3D objects less ugly
         gl.glEnable(gl.GL_LINE_SMOOTH)
         gl.glHint(gl.GL_LINE_SMOOTH_HINT, gl.GL_NICEST)
         # set the width of lines to 4 pixels
-        gl.glLineWidth(4)
+        gl.glLineWidth(line_width)
         # set PointCloud markers to 4 pixels in size
-        gl.glPointSize(4)
+        gl.glPointSize(point_size)
 
     @staticmethod
     def _gl_enable_lighting(scene):
@@ -692,6 +708,10 @@ class SceneViewer(pyglet.window.Window):
         if self._grid:
             self._grid.draw(mode=gl.GL_LINES)
 
+        # save a reference outside of the loop
+        geometry = self.scene.geometry
+        graph = self.scene.graph
+
         while len(node_names) > 0:
             count += 1
             current_node = node_names.popleft()
@@ -700,10 +720,10 @@ class SceneViewer(pyglet.window.Window):
                 continue
 
             # get the transform from world to geometry and mesh name
-            transform, geometry_name = self.scene.graph.get(current_node)
+            transform, geometry_name = graph.get(current_node)
 
             # if no geometry at this frame continue without rendering
-            if geometry_name is None:
+            if geometry_name is None or geometry_name not in self.vertex_list_mode:
                 continue
 
             # if a geometry is marked as fixed apply the inverse view transform
@@ -715,7 +735,7 @@ class SceneViewer(pyglet.window.Window):
                 transform = np.dot(transform, transform_fix)
 
             # get a reference to the mesh so we can check transparency
-            mesh = self.scene.geometry[geometry_name]
+            mesh = geometry[geometry_name]
             if mesh.is_empty:
                 continue
 
@@ -741,7 +761,7 @@ class SceneViewer(pyglet.window.Window):
             if self.view['axis'] == 'all':
                 self._axis.draw(mode=gl.GL_TRIANGLES)
             elif self.view['axis'] == 'without_world':
-                if count > 0:
+                if not util.allclose(transform, np.eye(4), atol=1e-5):
                     self._axis.draw(mode=gl.GL_TRIANGLES)
 
             # transparent things must be drawn last
