@@ -69,11 +69,14 @@ class ColorVisuals(Visuals):
                                           dtype=np.uint8),
             'material_shine': 77.0}
 
-        if face_colors is not None:
-            self.face_colors = face_colors
+        try:
+            if face_colors is not None:
+                self.face_colors = face_colors
 
-        if vertex_colors is not None:
-            self.vertex_colors = vertex_colors
+            if vertex_colors is not None:
+                self.vertex_colors = vertex_colors
+        except ValueError:
+            util.log.warning('unable to convert colors!')
 
     @caching.cache_decorator
     def transparency(self):
@@ -312,6 +315,8 @@ class ColorVisuals(Visuals):
                 else:
                     raise ValueError('unsupported name!!!')
                 self._cache.verify()
+                # return the stored copy of the colors
+                return self._data[key_colors]
         else:
             # colors have never been accessed
             if self.kind is None:
@@ -439,7 +444,7 @@ class ColorVisuals(Visuals):
         return color
 
     def to_texture(self):
-        from .materials import from_color
+        from .material import from_color
         from .texture import TextureVisuals
         mat, uv = from_color(vertex_colors=self.vertex_colors)
         return TextureVisuals(material=mat, uv=uv)
@@ -570,12 +575,16 @@ def to_rgba(colors, dtype=np.uint8):
     # integer value for opaque alpha given our datatype
     opaque = np.iinfo(dtype).max
 
+    if colors.dtype.kind == 'f':
+        # replace any `nan` or `inf` values with zero
+        colors[~np.isfinite(colors)] = 0.0
+
     if (colors.dtype.kind == 'f' and colors.max() < (1.0 + 1e-8)):
         colors = (colors * opaque).round().astype(dtype)
     elif (colors.max() <= opaque):
         colors = colors.astype(dtype)
     else:
-        raise ValueError('colors non- convertible!')
+        raise ValueError('colors non-convertible!')
 
     if util.is_shape(colors, (-1, 3)):
         # add an opaque alpha for RGB colors
@@ -584,7 +593,7 @@ def to_rgba(colors, dtype=np.uint8):
             opaque * np.ones(len(colors)))).astype(dtype)
     elif util.is_shape(colors, (3,)):
         # if passed a single RGB color add an alpha
-        colors = np.append(colors, opaque)
+        colors = np.append(colors, opaque).astype(dtype)
 
     if not (util.is_shape(colors, (4,)) or
             util.is_shape(colors, (-1, 4))):
@@ -735,7 +744,7 @@ def colors_to_materials(colors, count=None):
     # if we were only passed a single color
     if util.is_shape(rgba, (4,)) and count is not None:
         diffuse = rgba.reshape((-1, 4))
-        index = np.zeros(count, dtype=np.int)
+        index = np.zeros(count, dtype=np.int64)
     elif util.is_shape(rgba, (-1, 4)):
         # we were passed multiple colors
         # find the unique colors in the list to save as materials
